@@ -2,5 +2,5 @@
   function hello(world) {
     return 'Hello ' + world + '!';
   }
-  return hello(name);
-}('Forbes Lindesay'));
\ No newline at end of file
+  console.log(hello(name));
+}('Forbes Lindesay'));
